/* eslint-disable jsx-a11y/anchor-is-valid */
/**
 *
 * Header
 *
 */

import React, { memo, useState, useEffect } from 'react';
import { Navbar, Nav } from 'react-bootstrap';
// import styled from 'styled-components';
import { useTransition, animated } from 'react-spring';
import { Link } from 'react-router-dom';
import Cookies from 'js-cookie';
import messages from './messages';
// import junkshon logo
import junkshonLogo from '../../images/junkshon100pixels.png';
import { urlSwitcher } from '../../utils/urlSwitcher';
/**
 * @module Header
 */
function Header() {
  /**
   * @function Show - The animation state for the transition using useState
   */
  const [show, set] = useState(true);
  /**
   * @function Transition - react spring use transition function to slide it in
   */
  const transitions = useTransition(show, null, {
    from: { opacity: 0, right: '450px', position: 'relative', display: 'flex' },
    enter: {
      opacity: 1,
      right: 'unset',
      position: 'relative',
      display: 'inherit',
    },
    leave: { opacity: 0, left: '450px', position: 'relative', display: 'flex' },
  });

  return transitions.map(
    ({ item, key, props }) =>
      item && (
        <animated.div key={key} style={props}>
          <Navbar
            bg="dark"
            variant="dark"
            className="d-flex justify-content-between"
          >
            <Link to={Cookies.get('token') !== '' ? '/' : '/login'}>
              <Navbar.Brand>
                <img
                  alt=""
                  src={junkshonLogo}
                  width="30"
                  height="30"
                  className="d-inline-block align-top header-image"
                />{' '}
                <span className="menu-text">
                  {messages.header.defaultMessage}
                </span>
              </Navbar.Brand>
            </Link>
            <div className="d-flex justify-content-end p-2">
              <div className="text-light pr-2">
                {Cookies.get('company_name')} {Cookies.get('username')}
              </div>
              <a
                to=""
                onClick={() => {
                  Cookies.remove('token');
                }}
                href={urlSwitcher(process.env.NODE_ENV)}
              >
                <Nav.Item className="pr-2">
                  {Cookies.get('token') === null ? 'Login' : 'Logout'}
                </Nav.Item>
              </a>
              <div>
                <a href={urlSwitcher(process.env.NODE_ENV)}>
                  <i
                    title="Back to Aspire Platform"
                    className="far fa-home home-icon"
                  />
                </a>
              </div>
            </div>
          </Navbar>
        </animated.div>
      ),
  );
}

Header.propTypes = {};

export default memo(Header);
