/**
 *
 * ReusableTooltip
 *
 */

import React, { memo } from 'react';
import { OverlayTrigger, Tooltip } from 'react-bootstrap';
import PropTypes from 'prop-types';
// import styled from 'styled-components';

/**
 * This component wraps around the element you want the hover event to be on
 * @param {node} children - the target of the hover event
 * @param {string} content - content of the tooltip
 * @param {string} place - placement of the tooltip relatve to the children
 * @param {object} delay - delay tooltip on hover
 */
function ReusableTooltip({
  children,
  id,
  content = 'Custom Tooltip',
  place = 'top',
  delay = { show: 0, hide: 0 },
}) {
  const CustomTooltip = props => (
    <Tooltip {...props}>
      <div className="p-1">{content}</div>
    </Tooltip>
  );

  return (
    // using overlay trigger here as it listens for an overlay then shows a component
    <OverlayTrigger
      placement={place}
      delay={delay}
      overlay={CustomTooltip}
      id={id}
    >
      {children}
    </OverlayTrigger>
  );
}

ReusableTooltip.propTypes = {
  children: PropTypes.node,
  id: PropTypes.string,
  content: PropTypes.string,
  place: PropTypes.string,
  delay: PropTypes.object,
};

export default memo(ReusableTooltip);
