/**
 *
 * App.js
 *
 * This component is the skeleton around the actual pages, and should only
 * contain code that should be seen on all pages. (e.g. navigation bar)
 *
 */

import React, { useEffect } from 'react';
import { Switch, Route } from 'react-router-dom';

import HomePage from 'containers/HomePage/Loadable';
import NotFound from 'containers/NotFoundPage/Loadable';
import { connect } from 'react-redux';
import { compose } from 'redux';
import Cookies from 'js-cookie';
import { useCycle } from 'framer-motion';
import NavContainer from '../NavContainer/Loadable';
import GlobalStyle from '../../global-styles';
import Header from '../../components/Header/Loadable';
import { urlSwitcher } from '../../utils/urlSwitcher';

export function App() {
  const [openMenu, toggleOpenMenu] = useCycle(false, true);

  const handleToggle = state => toggleOpenMenu(prev => state || !prev);
  useEffect(() => {
    if (!Cookies.get('token')) {
      window.location.href = urlSwitcher(process.env.NODE_ENV);
    }
  }, [Cookies.get('token')]);

  return (
    <div>
      <Header />
      <NavContainer
        sidenavBackgroundColor="#343a40"
        handleToggle={handleToggle}
        openMenu={openMenu}
      >
        <Switch>
          <Route
            path="/"
            render={() => <HomePage />}
            // component={HomePage}
          />
          <Route component={NotFound} />
        </Switch>
      </NavContainer>
      <GlobalStyle />
    </div>
  );
}

function mapDispatchToProps(dispatch) {
  return {
    dispatch,
  };
}

const withConnect = connect(mapDispatchToProps);

export default compose(withConnect)(App);
