/**
 *
 * HomePage
 *
 */

import React, { memo, useEffect } from 'react';
import PropTypes from 'prop-types';
import Cookies from 'js-cookie';
import { Col, Row } from 'react-bootstrap';
import { connect } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { compose } from 'redux';
import injectSaga, { useInjectSaga } from 'utils/injectSaga';
import injectReducer, { useInjectReducer } from 'utils/injectReducer';
import { ModalContainer } from '../ModalContainer';
import makeSelectModalContainer from '../ModalContainer/selectors';
import modalContainerReducer from '../ModalContainer/reducer';
import modalContainerSaga from '../ModalContainer/saga';
import makeSelectReusableNotificationContainer from '../ReusableNotificationContainer/selectors';
import makeSelectHomePage from './selectors';
import reducer from './reducer';
import saga from './saga';
import notifreducer from '../ReusableNotificationContainer/reducer';
import notifsaga from '../ReusableNotificationContainer/saga';
import Header from '../../components/Header/Loadable';
import { ReusableNotificationContainer } from '../ReusableNotificationContainer';
import { toggleToastWithBody } from '../ReusableNotificationContainer/actions';
import 'react-toastify/dist/ReactToastify.css';
import loadingSpinnerContainerSaga from '../LoadingSpinnerContainer/saga';
import loadingSpinnerContainerReducer from '../LoadingSpinnerContainer/reducer';
import { LoadingSpinnerContainer } from '../LoadingSpinnerContainer';
import makeSelectLoadingSpinnerContainer from '../LoadingSpinnerContainer/selectors';

import { FireSpinnerReducer } from '../LoadingSpinnerContainer/actions';
import history from '../../utils/history';
import { HandleModalAction } from '../ModalContainer/actions';

export function HomePage(props) {
  return (
    <>
      <ReusableNotificationContainer
        reusableNotificationContainer={props.reusableNotification}
        notifications={[]}
      />
      <LoadingSpinnerContainer loadingSpinner={props.LoadingSpinnerContainer} />
      <ModalContainer
        dispatch={props.dispatch}
        modalContainer={props.modalContainer}
      />
      <div>
        <div>
          {Cookies.get('token')
            ? 'You are authenticated'
            : 'You are not authenticated, please go back to platform and login'}
        </div>
      </div>
      <div>
        <div>
          For notifications we use a library called React{' '}
          <a
            href="https://www.npmjs.com/package/react-toastify"
            target="_blank"
          >
            Toast
          </a>
        </div>
        <div>
          <button
            onClick={() => {
              props.dispatch(toggleToastWithBody('Test toast', 'success'));
            }}
          >
            Fire success toasty
          </button>
          <button
            onClick={() => {
              props.dispatch(toggleToastWithBody('Test toast', 'error'));
            }}
          >
            Fire error toasty
          </button>
        </div>
      </div>

      <button
        onClick={() => {
          props.dispatch(
            FireSpinnerReducer(
              !props.LoadingSpinnerContainer.active,
              'grow',
              'primary',
              'sm',
              '',
            ),
          );
          console.log(props);
        }}
      >
        Fire spinner
      </button>
      <button
        onClick={() => {
          const modalObject = {
            body: <div>This is a test modal body</div>,
            title: 'Test modal title to show the modal is created',
            centered: false,
          };

          props.dispatch(
            HandleModalAction(!props.modalContainer.active, modalObject),
          );
        }}
      >
        Fire modal
      </button>
    </>
  );
}

HomePage.propTypes = {
  dispatch: PropTypes.func.isRequired,
  reusableNotification: PropTypes.object,
};

const mapStateToProps = createStructuredSelector({
  homePage: makeSelectHomePage(),
  reusableNotification: makeSelectReusableNotificationContainer(),
  LoadingSpinnerContainer: makeSelectLoadingSpinnerContainer(),
  modalContainer: makeSelectModalContainer(),
});

function mapDispatchToProps(dispatch) {
  return {
    dispatch,
  };
}

const withConnect = connect(
  mapStateToProps,
  mapDispatchToProps,
);

export default compose(
  injectReducer({ key: 'homePage', reducer }),
  injectReducer({
    key: 'reusableNotificationContainer',
    reducer: notifreducer,
  }),
  injectSaga({ key: 'homePage', saga }),
  injectSaga({ key: 'reusableNotification', saga: notifsaga }),
  injectSaga({
    key: 'loadingSpinnerContainer',
    saga: loadingSpinnerContainerSaga,
  }),
  injectReducer({
    key: 'loadingSpinnerContainer',
    reducer: loadingSpinnerContainerReducer,
  }),
  injectReducer({ key: 'modalContainer', reducer: modalContainerReducer }),
  injectSaga({ key: 'modalContainer', saga: modalContainerSaga }),
  withConnect,
  memo,
)(HomePage);
