/**
 *
 * LoadingSpinnerContainer
 *
 */

import React, { memo } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { compose } from 'redux';

import injectSaga, { useInjectSaga } from 'utils/injectSaga';
import injectReducer, { useInjectReducer } from 'utils/injectReducer';
import { Spinner } from 'react-bootstrap';
import makeSelectLoadingSpinnerContainer from './selectors';
import reducer from './reducer';
import saga from './saga';
import { FireSpinnerReducer } from './actions';
import makeSelectHomePage from '../HomePage/selectors';
import homePageReducer from '../HomePage/reducer';
import homePageSaga from '../HomePage/saga';

export function LoadingSpinnerContainer(props) {
  useInjectReducer({ key: 'loadingSpinnerContainer', reducer });
  useInjectSaga({ key: 'loadingSpinnerContainer', saga });
  const { loadingSpinner } = props;
  return (
    <>
      {loadingSpinner.active === true ? (
        <Spinner
          animation={loadingSpinner.animation}
          role="status"
          size={loadingSpinner.size}
          variant={loadingSpinner.variant}
        >
          <span className="sr-only">Loading...</span>
        </Spinner>
      ) : null}
    </>
  );
}

LoadingSpinnerContainer.propTypes = {
  dispatch: PropTypes.func.isRequired,
};

const mapStateToProps = createStructuredSelector({
  loadingSpinnerContainer: makeSelectLoadingSpinnerContainer(),
  homePage: makeSelectHomePage(),
});

function mapDispatchToProps(dispatch) {
  return {
    dispatch,
  };
}

const withConnect = connect(
  mapStateToProps,
  mapDispatchToProps,
);

export default compose(
  injectReducer({ key: 'homePage', reducer: homePageReducer }),
  injectSaga({ key: 'homePage', saga: homePageSaga }),
  injectReducer({ key: 'loadingSpinnerContainer', reducer }),
  injectSaga({ key: 'loadingSpinnerContainer', saga }),
  withConnect,
  memo,
)(LoadingSpinnerContainer);
