/* eslint-disable react/destructuring-assignment */
/**
 *
 * ModalContainer
 *
 */

import React, { memo, useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { compose } from 'redux';
import { Modal } from 'react-bootstrap';
import injectSaga from 'utils/injectSaga';

import injectReducer from 'utils/injectReducer';

import homePageReducer from '../HomePage/reducer';
import homePageSaga from '../HomePage/saga';
import makeSelectHomePage from '../HomePage/selectors';
import makeSelectModalContainer from './selectors';
import reducer from './reducer';
import saga from './saga';
import { HandleModalAction } from './actions';

export function ModalContainer(props) {
  // state to handle modal opening
  const [show, setShow] = useState(false);
  const { modalContainer } = props;
  useEffect(() => {
    if (modalContainer.active === true) {
      setShow(true);
    }
  }, [modalContainer?.active]);

  return (
    <Modal
      show={modalContainer?.active}
      onHide={() => {
        props.dispatch(HandleModalAction(false, {}));
      }}
      centered={
        modalContainer?.modalObject.centered
          ? modalContainer?.modalObject.centered
          : false
      }
      dialogClassName={modalContainer?.modalObject?.dialogClassName}
    >
      <Modal.Header
        style={modalContainer?.modalObject?.headerStyle}
        closeButton
      >
        <Modal.Title>{modalContainer?.modalObject?.title}</Modal.Title>
      </Modal.Header>
      <Modal.Body>
        {props.children ? props.children : modalContainer?.modalObject.body}
      </Modal.Body>
      {props.footer && <Modal.Footer />}
    </Modal>
  );
}

ModalContainer.propTypes = {
  dispatch: PropTypes.func.isRequired,
  modalContainer: PropTypes.object,
  children: PropTypes.element,
  footer: PropTypes.bool,
};

const mapStateToProps = createStructuredSelector({
  modalContainer: makeSelectModalContainer(),
  homePage: makeSelectHomePage(),
});

function mapDispatchToProps(dispatch) {
  return {
    dispatch,
  };
}

const withConnect = connect(
  mapStateToProps,
  mapDispatchToProps,
);

export default compose(
  injectReducer({ key: 'homePage', reducer: homePageReducer }),
  injectSaga({ key: 'homePage', saga: homePageSaga }),
  injectReducer({ key: 'modalContainer', reducer }),
  injectSaga({ key: 'modalContainer', saga }),
  withConnect,
  memo,
)(ModalContainer);
