/* eslint-disable no-nested-ternary */
/* eslint-disable vars-on-top */
/**
 *
 * ReusableNotificationContainer
 *
 */

import React, { memo, useEffect } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { compose } from 'redux';

import { useInjectSaga } from 'utils/injectSaga';
import { useInjectReducer } from 'utils/injectReducer';
import { ToastContainer, toast } from 'react-toastify';
import makeSelectReusableNotificationContainer from './selectors';
import reducer from './reducer';
import saga from './saga';
import 'react-toastify/dist/ReactToastify.css';
/**
 * @module UIComponent - Reusable Notification
 */
// the type of notification it can be, error or success, this can be extended using toast docs
/**
 * @function types sets the notification type
 * @param {string} notiftype -  notification type
 */
// eslint-disable-next-line consistent-return
const types = notiftype => {
  if (notiftype === 'success') {
    return toast.success;
  }
  if (notiftype === 'error') {
    return toast.error;
  }
  return toast.error;
};
export function ReusableNotificationContainer(props) {
  // useInjectReducer({ key: 'reusableNotificationContainer', reducer });
  // useInjectSaga({ key: 'reusableNotificationContainer', saga });
  // console.error({props});
  const { id, body, type } = props.reusableNotificationContainer
    ? props.reusableNotificationContainer
    : {
        id: null,
        body: null,
        type: null,
      };
  const allToasts = props.reusableNotificationContainer;
  // the store toggle for sending a toast across muliple pages
  // toast id to get the toast content
  // notify is null so it resets on each call
  var notify = null;
  // setting up the notification object based on the id passed to it
  var notification = props.notifications.filter(x => x.id == id)[0];
  if (notification || body) {
    // set up notifiication type based on notification
    var notiftype = type
      ? types(type)
      : notification
      ? types(notification.type)
      : null;

    // set up the notification type showToast function
    notify = allToasts
      ? () => {
          notiftype(body || notification.body, {
            position: 'top-center',
            autoClose: 2250,
            hideProgressBar: false,
            closeOnClick: true,
            pauseOnHover: true,
            draggable: true,
            progress: undefined,
          });
        }
      : null;
  }
  // use effect on mount
  useEffect(() => {
    if (notify) {
      notify();
    }
  }, [allToasts]);

  if (!allToasts) {
    return null;
  }

  return (
    <div>
      <ToastContainer limit={1} />
    </div>
  );
}

const withConnect = connect();

ReusableNotificationContainer.propTypes = {
  reusableNotificationContainer: PropTypes.object,
  notifications: PropTypes.array,
};

export default compose(
  withConnect,
  memo,
)(ReusableNotificationContainer);
